Source<T> class abstract

Implementers

Constructors

Source.fromJsObject(T jsObject)
Creates a new JsObjectWrapper type from a jsObject.

Properties

dict → Map<String, dynamic>
Dict object.
no setter
hashCode → int
The hash code for this object.
no setterinherited
jsObject → T
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited